==> nextcloud-28.0.7.tgz: nextcloud/apps/twofactor_backupcodes/l10n/fr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Vous avez créé des codes de secours à deux facteurs pour votre compte",
    "Second-factor backup codes" : "Codes de récupération pour l’authentification en deux étapes",
    "Generate backup codes" : "Générer des codes de récupération",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Vous avez activé l'authentification en deux étapes mais vous n'avez pas généré de codes de secours. Ils sont nécessaires pour récupérer l'accès à votre compte en cas de perte de votre autre moyen de connexion.",
    "Backup code" : "Code de récupération",
    "Use backup code" : "Utiliser un code de récupération",
    "Two factor backup codes" : "Code de secours pour l'authentification double facteur.",
    "A two-factor auth backup codes provider" : "Un fournisseur de codes de récupération d'authentification à deux facteurs",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Les codes de récupération ont été générés. {used} codes sur {total} ont été utilisés.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Voici vos codes de récupération. Veuillez les sauvegarder et/ou les imprimer car vous ne pourrez plus y avoir accès ultérieurement",
    "Save backup codes" : "Sauvegarder les codes de récupération",
    "Print backup codes" : "Imprimer les codes de récupération",
    "Regenerate backup codes" : "Régénérer les codes de récupération",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vous régénérez les codes de récupération, vous invalidez automatiquement les anciens codes.",
    "An error occurred while generating your backup codes" : "Une erreur est survenue lors de la génération de vos codes de récupération",
    "{name} backup codes" : "{name} codes de récupération",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilisez l'un des codes de récupération que vous avez enregistrés lors de la configuration de l'authentification à deux facteurs.",
    "Submit" : "Soumettre"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/fr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Vous avez créé des codes de secours à deux facteurs pour votre compte",
    "Second-factor backup codes" : "Codes de récupération pour l’authentification en deux étapes",
    "Generate backup codes" : "Générer des codes de récupération",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Vous avez activé l'authentification en deux étapes mais vous n'avez pas généré de codes de secours. Ils sont nécessaires pour récupérer l'accès à votre compte en cas de perte de votre autre moyen de connexion.",
    "Backup code" : "Code de récupération",
    "Use backup code" : "Utiliser un code de récupération",
    "Two factor backup codes" : "Code de secours pour l'authentification double facteur.",
    "A two-factor auth backup codes provider" : "Un fournisseur de codes de récupération d'authentification à deux facteurs",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Les codes de récupération ont été générés. {used} codes sur {total} ont été utilisés.",
    "Save backup codes" : "Sauvegarder les codes de récupération",
    "Print backup codes" : "Imprimer les codes de récupération",
    "Regenerate backup codes" : "Régénérer les codes de récupération",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vous régénérez les codes de récupération, vous invalidez automatiquement les anciens codes.",
    "An error occurred while generating your backup codes" : "Une erreur est survenue lors de la génération de vos codes de récupération",
    "{name} backup codes" : "{name} codes de récupération",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilisez l'un des codes de récupération que vous avez enregistrés lors de la configuration de l'authentification à deux facteurs.",
    "Submit" : "Soumettre",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Voici vos codes de récupération. Veuillez les sauvegarder et/ou les imprimer car vous ne pourrez plus y avoir accès ultérieurement"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
